@@ -85,7 +85,8 @@ func outputFormat(w io.Writer, addExtension bool, baseFilename, format, fsRoot,
 	switch strings.ToLower(format) {
 	case "lovely", "default":
 		alsoStdout = true
-		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput, codeTheme, !disableColours))
+		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput, codeTheme,
+			!disableColours, noCode))
 	case "json":
 		factory.AsJSON()
 		makeRelative = false
@@ -96,7 +97,7 @@ func outputFormat(w io.Writer, addExtension bool, baseFilename, format, fsRoot,
 	case "junit":
 		factory.AsJUnit()
 	case "text":
-		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput, codeTheme, !disableColours)).WithColoursEnabled(false)
+		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput, codeTheme, !disableColours, false)).WithColoursEnabled(false)
 	case "sarif":
 		factory.AsSARIF()
 	case "gif":
